pub struct DetachedItem<T> { /* private fields */ }Expand description
A detached handle to a match candidate.
Unlike an Item, which has a lifetime tied to the Snapshot or Injector from which it was
created, a DetachedItem owns a handle to the underlying data and will persist even if the original
Nucleo matcher has been dropped.
Similarly to an injector, holding this handle will prevent the underlying data from being dropped. This handle is internally reference counted and can be cloned cheaply.
This handle implements PartialEq regardless of the value T. Equality is tested by checking that
both items originate from the same matcher and that the internal indices are the same.
Implementations
Sourceimpl<T> DetachedItem<T>
impl<T> DetachedItem<T>